package org.gcube.portlets.user.td.gwtservice.shared.tr.paging;

import java.io.Serializable;

/**
 * 
 * @author "Giancarlo Panichi" <a
 *         href="mailto:g.panichi@isti.cnr.it">g.panichi@isti.cnr.it</a>
 * 
 */
public class CodelistPagingLoadConfig implements Serializable {

	private static final long serialVersionUID = -8831947012755493644L;

	protected int offset;
	protected int limit;
	protected Direction direction;
	protected String filter;
	
	public CodelistPagingLoadConfig(){}
	
	public CodelistPagingLoadConfig(int offset, int limit, Direction direction, String filter){
		this.offset=offset;
		this.limit=limit;
		this.direction=direction;
		this.filter=filter;
	}
	
	
	public int getOffset() {
		return offset;
	}

	public void setOffset(int offset) {
		this.offset = offset;
	}

	public int getLimit() {
		return limit;
	}

	public void setLimit(int limit) {
		this.limit = limit;
	}

	public Direction getDirection() {
		return direction;
	}

	public void setDirection(Direction direction) {
		this.direction = direction;
	}

	public String getFilter() {
		return filter;
	}

	public void setFilter(String filter) {
		this.filter = filter;
	}

	@Override
	public String toString() {
		return "CodelistPagingLoadConfig [offset=" + offset + ", limit="
				+ limit + ", direction=" + direction + ", filter=" + filter
				+ "]";
	}

}
